Class: Google::Cloud::Recommender::V1::OperationGroup
- Inherits:
-
Object
- Object
- Google::Cloud::Recommender::V1::OperationGroup
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/recommender/v1/recommendation.rb
Overview
Group of operations that need to be performed atomically.
Instance Attribute Summary collapse
-
#operations ⇒ ::Array<::Google::Cloud::Recommender::V1::Operation>
List of operations across one or more resources that belong to this group.
Instance Attribute Details
#operations ⇒ ::Array<::Google::Cloud::Recommender::V1::Operation>
Returns List of operations across one or more resources that belong to this group. Loosely based on RFC6902 and should be performed in the order they appear.
134 135 136 137 |
# File 'proto_docs/google/cloud/recommender/v1/recommendation.rb', line 134 class OperationGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |